==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-drools/drools-drl/drools-drl-extensions/src/main/java/org/drools/drl/extensions/DecisionTableProvider.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.drools.drl.extensions;

import java.io.File;
import java.io.InputStream;
import java.util.List;
import java.util.Map;

import org.kie.api.internal.utils.KieService;
import org.kie.api.io.Resource;
import org.kie.internal.builder.DecisionTableConfiguration;

public interface DecisionTableProvider extends KieService {

    String loadFromResource(Resource resource,
                            DecisionTableConfiguration configuration);

    List<String> loadFromInputStreamWithTemplates(Resource resource,
                                                  DecisionTableConfiguration configuration);

    Map<String,List<String[]>> loadPropertiesFromFile(File file, DecisionTableConfiguration configuration);

    Map<String,List<String[]>> loadPropertiesFromInputStream(InputStream inputStream, DecisionTableConfiguration configuration);
}

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-drools/drools-drl/drools-drl-extensions/src/main/java/org/drools/drl/extensions/DecisionTableProvider.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.drools.drl.extensions;

import java.io.File;
import java.io.InputStream;
import java.util.List;
import java.util.Map;

import org.kie.api.internal.utils.KieService;
import org.kie.api.io.Resource;
import org.kie.internal.builder.DecisionTableConfiguration;

public interface DecisionTableProvider extends KieService {

    String loadFromResource(Resource resource, DecisionTableConfiguration configuration);

    List<String> loadFromInputStreamWithTemplates(Resource resource, DecisionTableConfiguration configuration);

    Map<String,List<String[]>> loadPropertiesFromFile(File file, DecisionTableConfiguration configuration);

    Map<String,List<String[]>> loadPropertiesFromInputStream(InputStream inputStream, DecisionTableConfiguration configuration);

    void clearCompilerCache();
}
